/****************************************************************************
 *
 * Filename:    ps4000Wrap.h
 * Copyright:   Pico Technology Limited 2013
 * Author:      HSM
 * Description:
 *
 * This header defines the interface to the wrapper dll for the 
 *	PicoScope4000 series of PC Oscilloscopes.
 *
 ****************************************************************************/

#ifndef __PS4000WRAP_H__
#define __PS4000WRAP_H__

#include "ps4000Api.h"

#ifdef __cplusplus
	#define PREF0 extern "C"
	#define TYPE_ENUM
#else
	#define PREF0
	#define TYPE_ENUM enum
#endif

#ifdef WIN32
	typedef unsigned __int64 u_int64_t;
	#ifdef PREF1
	  #undef PREF1
	#endif
	#ifdef PREF2
	  #undef PREF2
	#endif
	#ifdef PREF3
	  #undef PREF3
	#endif
	/*	If you are dynamically linking PS3000A.DLL into your project #define DYNLINK here
	 */
	#ifdef DYNLINK
	  #define PREF1 typedef
		#define PREF2
		#define PREF3(x) (__stdcall *x)
	#else
	  #define PREF1
		#ifdef _USRDLL
			#define PREF2 __declspec(dllexport) __stdcall
		#else
			#define PREF2 __declspec(dllimport) __stdcall
		#endif
	  #define PREF3(x) x
	#endif
#else
	/* Define a 64-bit integer type */
	#include <stdint.h>
	typedef int64_t __int64;

	#ifdef DYNLINK
		#define PREF1 typedef
		#define PREF2
		#define PREF3(x) (*x)
	#else
		#ifdef _USRDLL
			#define PREF1 __attribute__((visibility("default")))
		#else
			#define PREF1
		#endif
		#define PREF2
		#define PREF3(x) x
	#endif
	#define __stdcall
#endif

// Function definitions

extern short __declspec(dllexport) __stdcall RunBlock
	(
		short handle, 
		long preTriggerSamples, 
		long postTriggerSamples, 
        unsigned long timebase, 
		short oversample, 
		short segmentIndex
	);

extern short __declspec(dllexport) __stdcall GetStreamingLatestValues
	(
		short handle
	);

extern unsigned long __declspec(dllexport) __stdcall AvailableData
	(
		short handle,
		unsigned long *startIndex
	);

extern short __declspec(dllexport) __stdcall AutoStopped
	(
		short handle
	);

extern short __declspec(dllexport) __stdcall IsReady
	(
		short handle
	);

extern short __declspec(dllexport) __stdcall IsTriggerReady
	(
		short handle, 
		unsigned long *triggeredAt
	);

extern short __declspec(dllexport) __stdcall ClearTriggerReady(void);

extern short __declspec(dllexport) __stdcall SetTriggerConditions
	(
		short handle, 
		int *conditionsArray, 
		short nConditions
	);

extern short __declspec(dllexport) __stdcall SetTriggerProperties
	(
		short handle, 
		int *propertiesArray, 
		short nProperties, 
		short auxEnable, 
		long autoTrig
	);

extern short __declspec(dllexport) __stdcall SetRapidBlockDataBuffers
	(
		short handle, 
		short channel, 
		short *buffer, 
		short nCaptures, 
		unsigned long nSamples
	);

#endif




